﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
/* ネームスペースを追加 */
using SettingsToAccessDB;
using SettingsToAccessDB.DAOs;

namespace SettingsToAccessDBSample
{
    public partial class Form1 : SizeChangableForm /* SizeChangableForm を継承 */
    {
        private readonly string header = "sampleProgram";
        private ControlSizeChangeAdapter sizeAdapter = null;
        private ControlSizeSaveAdapter saveAdapter = null;

        // コンストラクタ
        public Form1()
        {
            InitializeComponent();

            // サイズ変更委譲アダプタクラスを生成
            this.sizeAdapter = new ControlSizeChangeAdapter();
            // サイズ変更委譲アダプタ経由で、コントロール群を初期化
            this.sizeAdapter.InitSize(this);

            // サイズ保存委譲アダプタクラスを生成
            this.saveAdapter = new ControlSizeSaveAdapter();

        }

        // フォームをロードしたとき
        private void Form1_Load(object sender, EventArgs e)
        {
            /* using で dispose()させるコネクションオブジェクトDAOContextを生成 */
            using (DAOContext con = new DAOContext(AccessConstring.SettingConString))
            {
                // コネクションオープン
                con.OpenConnection();


                //コントロールのサイズのリセット
                DialogResult ret = MessageBox.Show("コントロール位置をリセットしますか？", "確認", MessageBoxButtons.OKCancel);
                if (DialogResult.OK.Equals(ret))
                {
                    // フォームサイズのリセット
                    this.ResetTopLeftHeightWidth(con, this.header);
                    // テキストのリセット
                    this.textSavableTextBox1.ResetTopLeftHeightWidth(con, this.header);
                    this.textSavableComboBox1.ResetTopLeftHeightWidth(con, this.header);
                    this.textSavableTextBox1.ResetTopLeftHeightWidth(con, this.header);
                    // サイズ・位置のリセット
                    this.sizeChangablePanel1.ResetTopLeftHeightWidth(con, this.header);
                    this.textSavableComboBox1.ResetTopLeftHeightWidth(con, this.header);
                    this.sizeChangableButton1.ResetTopLeftHeightWidth(con, this.header);
                    this.sizeChangableButton2.ResetTopLeftHeightWidth(con, this.header);
                }
                
                // フォームサイズの読み出し
                this.LoadData(con, this.header);
                // テキストの読み出し
                this.textSavableTextBox1.LoadData(con, this.header);
                this.textSavableComboBox1.LoadData(con, this.header);
                this.textSavableListBox1.LoadData(con, this.header);
                // サイズ・位置の読み出し
                this.sizeChangablePanel1.LoadData(con, this.header);
                this.sizeChangableComboBox1.LoadData(con, this.header);
                this.sizeChangableButton1.LoadData(con, this.header);
                this.sizeChangableButton2.LoadData(con, this.header);

                // コネクションクローズ
                con.CloseConnection();
            }

            /*
            // このように書くこともできます。
            using (DAOContext con = new DAOContext(AccessConstring.SettingConString))
            {
                // コネクションオープン
                con.OpenConnection();

                // ロード
                this.saveAdapter.LoadData(this, con, this.header);

                // コネクションクローズ
                con.CloseConnection();
            }
             */
        }

        // フォームが閉じるとき
        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            /* using で dispose()させるコネクションオブジェクトDAOContextを生成 */
            using (DAOContext con = new DAOContext(AccessConstring.SettingConString))
            {
                // コネクションオープン
                con.OpenConnection();

                // フォームサイズの保存
                this.SaveData(con, this.header);
                // テキストの保存
                this.textSavableTextBox1.SaveData(con, this.header);
                this.textSavableComboBox1.SaveData(con, this.header);
                this.textSavableListBox1.SaveData(con, this.header);
                // サイズ・位置の保存
                this.sizeChangablePanel1.SaveData(con, this.header);
                this.sizeChangableComboBox1.SaveData(con, this.header);
                this.sizeChangableButton1.SaveData(con, this.header);
                this.sizeChangableButton2.SaveData(con, this.header);

                // コネクションクローズ
                con.CloseConnection();
            }

            /*
            // このように書くこともできます。
            using (DAOContext con = new DAOContext(AccessConstring.SettingConString))
            {
                // コネクションオープン
                con.OpenConnection();

                // 保存
                this.saveAdapter.SaveData(this, con, this.header);

                // コネクションクローズ
                con.CloseConnection();
            }
            */
        }

        // Enterキーが押されたときテキストをリストに追加
        private void textSavableComboBox1_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Enter)
            {
                this.textSavableComboBox1.Items.Add(this.textSavableComboBox1.Text);
                e.Handled = true;
            }
        }

        // リストボックスにテキストをリストに追加
        private void sizeChangableButton1_Click(object sender, EventArgs e)
        {
            this.textSavableListBox1.Items.Add(this.textSavableTextBox1.Text);
        }

        // サイズを上げるとき
        private void buttonUp_Click(object sender, EventArgs e)
        {
            int ratio = 0;
            int.TryParse(this.SizeText.Text, out ratio);
            ratio += 10;
            if (ratio < 50) ratio = 50;
            if (ratio > 200) ratio = 200;

            this.SizeText.Text = ratio.ToString();
        }

        // サイズを下げるとき
        private void buttonDown_Click(object sender, EventArgs e)
        {
            int ratio = 0;
            int.TryParse(this.SizeText.Text, out ratio);
            ratio -= 10;
            if (ratio < 50) ratio = 50;
            if (ratio > 200) ratio = 200;

            this.SizeText.Text = ratio.ToString();

        }


        // サイズ比率が変更されたとき
        bool isFirst = true;
        private void SizeText_TextChanged(object sender, EventArgs e)
        {
            if (isFirst)
            {
                isFirst = false;
                return;
            }
            int ratio = 100;
            int.TryParse(this.SizeText.Text, out ratio);
            if (ratio < 50) ratio = 50;
            if (ratio > 200) ratio = 200;

            // サイズ変更委譲アダプタ経由で、サイズ変更
            this.sizeAdapter.ChangeSize(this, ratio);
        }

        //マウスのクリック位置を記憶
        private Point mousePoint;
        //マウスのボタンが押されたとき
        private void sizeChangablePanel1_MouseDown(object sender, MouseEventArgs e)
        {
            if ((e.Button & MouseButtons.Left) == MouseButtons.Left)
            {
                //位置を記憶する
                mousePoint = new Point(e.X, e.Y);
            }
        }
        //マウスが動いたとき
        private void sizeChangablePanel1_MouseMove(object sender, MouseEventArgs e)
        {
            if ((e.Button & MouseButtons.Left) == MouseButtons.Left)
            {
                this.sizeChangablePanel1.Left += e.X - mousePoint.X;
                this.sizeChangablePanel1.Top += e.Y - mousePoint.Y;
                //または、つぎのようにする
                //this.Location = new Point(
                //    this.Location.X + e.X - mousePoint.X,
                //    this.Location.Y + e.Y - mousePoint.Y);
            }        
        }
        //マウスのボタンが押されたとき
        private void labelDrag_MouseDown(object sender, MouseEventArgs e)
        {
            if ((e.Button & MouseButtons.Left) == MouseButtons.Left)
            {
                //位置を記憶する
                mousePoint = new Point(e.X, e.Y);
            }
        }
        //マウスが動いたとき
        private void labelDrag_MouseMove(object sender, MouseEventArgs e)
        {
            if ((e.Button & MouseButtons.Left) == MouseButtons.Left)
            {
                this.sizeChangablePanel1.Left += e.X - mousePoint.X;
                this.sizeChangablePanel1.Top += e.Y - mousePoint.Y;
                //または、つぎのようにする
                //this.Location = new Point(
                //    this.Location.X + e.X - mousePoint.X,
                //    this.Location.Y + e.Y - mousePoint.Y);
            }        

        }


    }
}
